@@ -1,8 +1,4 @@
-#ifdef __APPLE__
-#include <OpenGL/glu.h>
-#else
 #include <GL/glu.h>
-#endif
 
 #ifndef GLU_VERSION_1_0
 #define GLU_VERSION_1_0 1
@@ -10,9 +6,9 @@
 
 #ifdef GLU_VERSION_1_0
 #ifndef GLU_VERSION_1_1
-typedef GLUnurbs	GLUnurbsObj;
+typedef GLUnurbs		GLUnurbsObj;
 typedef GLUtriangulatorObj	GLUtriangulatorObj;
-typedef GLUquadricObj	GLUquadricObjObj;
+typedef GLUquadricObj		GLUquadricObjObj;
 #endif
 #endif
 
